==> ZenTaoALM.12.4.1.int.zip: zentaoalm/module/repo/lang/fr.php <==
<?php
$lang->repo->common          = 'Référentiel';
$lang->repo->browse          = 'Aff';
$lang->repo->viewRevision    = 'Aff Modifs';
$lang->repo->create          = 'Créer';
$lang->repo->createAction    = 'Créer Ref';
$lang->repo->maintain        = 'Liste Ref';
$lang->repo->edit            = 'Editer';
$lang->repo->editAction      = 'Editer Ref';
$lang->repo->delete          = 'Suppr. Ref';
$lang->repo->showSyncCommit  = 'Afficher Synchronisation';
$lang->repo->ajaxSyncCommit  = 'Interface: Ajax Sync Note';
$lang->repo->setRules        = 'Fixer règles';
$lang->repo->download        = 'Download File';
$lang->repo->downloadDiff    = 'Download Diff';
$lang->repo->diffAction      = 'Révision Diff';
$lang->repo->revisionAction  = 'Détail Révision';
$lang->repo->blameAction     = 'Blâme du Référentiel';
$lang->repo->addBug          = 'Ajout Révision';
$lang->repo->editBug         = 'Editer Bug';
$lang->repo->deleteBug       = 'Suppr. Bug';
$lang->repo->addComment      = 'Ajout Comment.';
$lang->repo->editComment     = 'Edit. Comment';
$lang->repo->deleteComment   = 'Suppr. Comment';

$lang->repo->submit     = 'Soumettre';
$lang->repo->cancel     = 'Annuler';
$lang->repo->addComment = 'Ajout Comment';

$lang->repo->product  = $lang->productCommon;
$lang->repo->module   = 'Module';
$lang->repo->project  = $lang->projectCommon;
$lang->repo->type     = 'Type';
$lang->repo->assign   = 'Assigner à';
$lang->repo->title    = 'Titre';
$lang->repo->detile   = 'Détail';
$lang->repo->lines    = 'Lignes';
$lang->repo->line     = 'Ligne';
$lang->repo->expand   = 'Déplier';
$lang->repo->collapse = 'Replier';

$lang->repo->id        = 'ID';
$lang->repo->SCM       = 'Type';
$lang->repo->name      = 'Nom';
$lang->repo->path      = 'Chemin';
$lang->repo->prefix    = 'Préfixe';
$lang->repo->config    = 'Config';
$lang->repo->desc      = 'Description';
$lang->repo->account   = 'Nom Utilisateur';
$lang->repo->password  = 'Password';
$lang->repo->encoding  = 'Encodage';
$lang->repo->client    = 'Chemin Client';
$lang->repo->size      = 'Taille';
$lang->repo->revision  = 'Révision';
$lang->repo->revisionA = 'Révision';
$lang->repo->revisions = 'Révision';
$lang->repo->time      = 'Date';
$lang->repo->committer = 'Committeur';
$lang->repo->commits   = 'Commits';
$lang->repo->synced    = 'Initialise Sync';
$lang->repo->lastSync  = 'Dern Sync';
$lang->repo->deleted   = 'Supprimé';
$lang->repo->commit    = 'Commit';
$lang->repo->comment   = 'Comment';
$lang->repo->view      = 'Voir Fichier';
$lang->repo->viewA     = 'Voir';
$lang->repo->log       = 'Log Révision';
$lang->repo->blame     = 'Blâme';
$lang->repo->date      = 'Date';
$lang->repo->diff      = 'Diff';
$lang->repo->diffAB    = 'Diff';
$lang->repo->diffAll   = 'Toutes Diff';
$lang->repo->viewDiff  = 'Voir diff';
$lang->repo->allLog    = 'Toutes Révisions';
$lang->repo->location  = 'Localisation';
$lang->repo->file      = 'Fichier';
$lang->repo->action    = 'Action';
$lang->repo->code      = 'Code';
$lang->repo->review    = 'Révision Ref';
$lang->repo->acl       = 'Privilège';
$lang->repo->group     = 'Groupe';
$lang->repo->user      = 'User';
$lang->repo->info      = 'Info Version';

$lang->repo->title      = 'Titre';
$lang->repo->status     = 'Statut';
$lang->repo->openedBy   = 'Créé par';
$lang->repo->assignedTo = 'Assigné à';
$lang->repo->openedDate = 'Date Création';

$lang->repo->latestRevision = 'Dernière Révision';
$lang->repo->actionInfo     = "Ajouté par %s dans %s";
$lang->repo->changes        = "Change Log";
$lang->repo->reviewLocation = "Fichier: %s@%s, ligne:%s - %s";
$lang->repo->commentEdit    = '<i class="icon-pencil"></i>';
$lang->repo->commentDelete  = '<i class="icon-remove"></i>';
$lang->repo->allChanges     = "Autres Changements";
$lang->repo->commitTitle    = "Le %sème Commit";
$lang->repo->mark           = "Mark Tag";
$lang->repo->split          = "Split Mark";

$lang->repo->objectRule   = 'Object Rule';
$lang->repo->objectIdRule = 'Object ID Rule';
$lang->repo->actionRule   = 'Action Rule';
$lang->repo->manHourRule  = 'Man-hour Rule';
$lang->repo->ruleUnit     = "Unit";
$lang->repo->ruleSplit    = "Plusieurs mots-clés sont séparés par ';'. Par exemple : plusieurs mots clés tâche : Tâche;tâche";

$lang->repo->viewDiffList['inline'] = 'Interligne';
$lang->repo->viewDiffList['appose'] = 'Parallèle';

$lang->repo->encryptList['plain']  = "Pas d'encodage";
$lang->repo->encryptList['base64'] = 'BASE64';

$lang->repo->logStyles['A'] = 'Ajout';
$lang->repo->logStyles['M'] = 'Modification';
$lang->repo->logStyles['D'] = 'Suppression';

$lang->repo->encodingList['utf_8'] = 'UTF-8';
$lang->repo->encodingList['gbk']   = 'GBK';

$lang->repo->scmList['Git']        = 'Git';
$lang->repo->scmList['Subversion'] = 'Subversion';

$lang->repo->notice                 = new stdclass();
$lang->repo->notice->syncing        = 'Synchronisation en cours. Veuillez patienter ...';
$lang->repo->notice->syncComplete   = 'Synchronisé. Vous allez être redirigé ...';
$lang->repo->notice->syncedCount    = "Le nombre d'enregistrements synchronisés est ";
$lang->repo->notice->delete         = 'Etes vous certain de vouloir supprimer ce référentiel ?';
$lang->repo->notice->successDelete  = 'Le référentiel est supprimé.';
$lang->repo->notice->commentContent = 'Commentaire';
$lang->repo->notice->deleteBug      = 'Êtes-vous sûr de vouloir supprimer ce bug ?';
$lang->repo->notice->deleteComment  = 'Êtes-vous certain de vouloir supprimer ce commentaire ?';
$lang->repo->notice->lastSyncTime   = 'Dern Sync:';

$lang->repo->rules = new stdclass();
$lang->repo->rules->exampleLabel = "Comment Exemple";
$lang->repo->rules->example['task']['start']  = "%start% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['task']['finish'] = "%finish% %task% %id%1%split%2 %cost%%consumedmark%10%cunit%";
$lang->repo->rules->example['task']['effort'] = "%effort% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['bug']['resolve'] = "%resolve% %bug% %id%1%split%2";

$lang->repo->error                = new stdclass();
$lang->repo->error->useless       = 'Votre serveur a désactivé exec et shell_exec, il ne peut donc pas être appliqué.';
$lang->repo->error->connect       = "La connexion au référentiel a échoué. Veuillez saisir correctement le nom d'utilisateur, le mot de passe et l'adresse du référentiel !";
$lang->repo->error->version       = 'Version 1.8+ de https et du protocole svn est requis. Veuillez mettre à jour vers la dernière version ! Allez à http://subversion.apache.org/';
$lang->repo->error->path          = "L'adresse du référentiel est le chemin du fichier, ex: /home/test";
$lang->repo->error->cmd           = 'Erreur du Client !';
$lang->repo->error->diff          = 'Deux version doivent être sélectionnées.';
$lang->repo->error->product       = "Veuillez sélectionner un {$lang->productCommon}!";
$lang->repo->error->commentText   = 'Veuillez entrer du contenu pour une révision !';
$lang->repo->error->comment       = 'Veuillez entrer le contenu du commentaire !';
$lang->repo->error->title         = 'Veuillez saisir un titre !';
$lang->repo->error->accessDenied  = "Vous n'avez pas les privilèges d'accéder au référentiel.";
$lang->repo->error->noFound       = 'Le référentiel est non trouvé.';
$lang->repo->error->noFile        = "%s n'existe pas.";
$lang->repo->error->noPriv        = "Le programme n'a pas les privilèges pour basculer vers %s";
$lang->repo->error->output        = "La commande est: %s\nL'erreur est (%s): %s\n";
$lang->repo->error->clientVersion = "La version du client est trop ancienne, veuillez mettre à niveau ou changer le client SVN";
$lang->repo->error->encoding      = "L'encodage est peut-être erroné. Veuillez modifier l'encodage et réessayer.";

$lang->repo->syncTips      = '<strong>Vous pouvez trouver la référence sur la façon de définir la synchronisation Git à partir de la page se trouvant <a target="_blank" href="https://www.zentao.pm/book/zentaomanual/free-open-source-project-management-software-git-105.html">ici</a>.</strong>';
$lang->repo->encodingsTips = "Les encodages des commentaires de validation peuvent être des valeurs séparées par des virgules，ex: utf-8";

$lang->repo->example              = new stdclass();
$lang->repo->example->client      = new stdclass();
$lang->repo->example->path        = new stdclass();
$lang->repo->example->client->git = "ex: /usr/bin/git";
$lang->repo->example->client->svn = "ex: /usr/bin/svn";
$lang->repo->example->path->git   = "ex: /home/user/myproject";
$lang->repo->example->path->svn   = "ex: http://example.googlecode.com/svn/trunk/myproject";
$lang->repo->example->config      = "Le répertoire de configuration est requis en https. Utilisez '--config-dir' pour générer le répertoire de configuration.";
$lang->repo->example->encoding    = "encodage d'entrée des fichiers";

$lang->repo->typeList['standard']    = 'Standard';
$lang->repo->typeList['performance'] = 'Performance';
$lang->repo->typeList['security']    = 'Securité';
$lang->repo->typeList['redundancy']  = 'Redondance';
$lang->repo->typeList['logicError']  = 'Erreur Logique';

==> ZenTaoALM.12.4.2.int.zip: zentaoalm/module/repo/lang/fr.php <==
<?php
$lang->repo->common          = 'Référentiel';
$lang->repo->browse          = 'Aff';
$lang->repo->viewRevision    = 'Aff Modifs';
$lang->repo->create          = 'Créer';
$lang->repo->createAction    = 'Créer Ref';
$lang->repo->maintain        = 'Liste Ref';
$lang->repo->edit            = 'Editer';
$lang->repo->editAction      = 'Editer Ref';
$lang->repo->delete          = 'Suppr. Ref';
$lang->repo->showSyncCommit  = 'Afficher Synchronisation';
$lang->repo->ajaxSyncCommit  = 'Interface: Ajax Sync Note';
$lang->repo->setRules        = 'Fixer règles';
$lang->repo->download        = 'Download File';
$lang->repo->downloadDiff    = 'Download Diff';
$lang->repo->diffAction      = 'Révision Diff';
$lang->repo->revisionAction  = 'Détail Révision';
$lang->repo->blameAction     = 'Blâme du Référentiel';
$lang->repo->addBug          = 'Ajout Révision';
$lang->repo->editBug         = 'Editer Bug';
$lang->repo->deleteBug       = 'Suppr. Bug';
$lang->repo->addComment      = 'Ajout Comment.';
$lang->repo->editComment     = 'Edit. Comment';
$lang->repo->deleteComment   = 'Suppr. Comment';

$lang->repo->submit     = 'Soumettre';
$lang->repo->cancel     = 'Annuler';
$lang->repo->addComment = 'Ajout Comment';

$lang->repo->product  = $lang->productCommon;
$lang->repo->module   = 'Module';
$lang->repo->project  = $lang->projectCommon;
$lang->repo->type     = 'Type';
$lang->repo->assign   = 'Assigner à';
$lang->repo->title    = 'Titre';
$lang->repo->detile   = 'Détail';
$lang->repo->lines    = 'Lignes';
$lang->repo->line     = 'Ligne';
$lang->repo->expand   = 'Déplier';
$lang->repo->collapse = 'Replier';

$lang->repo->id        = 'ID';
$lang->repo->SCM       = 'Type';
$lang->repo->name      = 'Nom';
$lang->repo->path      = 'Chemin';
$lang->repo->prefix    = 'Préfixe';
$lang->repo->config    = 'Config';
$lang->repo->desc      = 'Description';
$lang->repo->account   = 'Nom Utilisateur';
$lang->repo->password  = 'Password';
$lang->repo->encoding  = 'Encodage';
$lang->repo->client    = 'Chemin Client';
$lang->repo->size      = 'Taille';
$lang->repo->revision  = 'Révision';
$lang->repo->revisionA = 'Révision';
$lang->repo->revisions = 'Révision';
$lang->repo->time      = 'Date';
$lang->repo->committer = 'Committeur';
$lang->repo->commits   = 'Commits';
$lang->repo->synced    = 'Initialise Sync';
$lang->repo->lastSync  = 'Dern Sync';
$lang->repo->deleted   = 'Supprimé';
$lang->repo->commit    = 'Commit';
$lang->repo->comment   = 'Comment';
$lang->repo->view      = 'Voir Fichier';
$lang->repo->viewA     = 'Voir';
$lang->repo->log       = 'Log Révision';
$lang->repo->blame     = 'Blâme';
$lang->repo->date      = 'Date';
$lang->repo->diff      = 'Diff';
$lang->repo->diffAB    = 'Diff';
$lang->repo->diffAll   = 'Toutes Diff';
$lang->repo->viewDiff  = 'Voir diff';
$lang->repo->allLog    = 'Toutes Révisions';
$lang->repo->location  = 'Localisation';
$lang->repo->file      = 'Fichier';
$lang->repo->action    = 'Action';
$lang->repo->code      = 'Code';
$lang->repo->review    = 'Révision Ref';
$lang->repo->acl       = 'Privilège';
$lang->repo->group     = 'Groupe';
$lang->repo->user      = 'User';
$lang->repo->info      = 'Info Version';

$lang->repo->title      = 'Titre';
$lang->repo->status     = 'Statut';
$lang->repo->openedBy   = 'Créé par';
$lang->repo->assignedTo = 'Assigné à';
$lang->repo->openedDate = 'Date Création';

$lang->repo->latestRevision = 'Dernière Révision';
$lang->repo->actionInfo     = "Ajouté par %s dans %s";
$lang->repo->changes        = "Change Log";
$lang->repo->reviewLocation = "Fichier: %s@%s, ligne:%s - %s";
$lang->repo->commentEdit    = '<i class="icon-pencil"></i>';
$lang->repo->commentDelete  = '<i class="icon-remove"></i>';
$lang->repo->allChanges     = "Autres Changements";
$lang->repo->commitTitle    = "Le %sème Commit";
$lang->repo->mark           = "Mark Tag";
$lang->repo->split          = "Split Mark";

$lang->repo->objectRule   = 'Object Rule';
$lang->repo->objectIdRule = 'Object ID Rule';
$lang->repo->actionRule   = 'Action Rule';
$lang->repo->manHourRule  = 'Man-hour Rule';
$lang->repo->ruleUnit     = "Unit";
$lang->repo->ruleSplit    = "Plusieurs mots-clés sont séparés par ';'. Par exemple : plusieurs mots clés tâche : Tâche;tâche";

$lang->repo->viewDiffList['inline'] = 'Interligne';
$lang->repo->viewDiffList['appose'] = 'Parallèle';

$lang->repo->encryptList['plain']  = "Pas d'encodage";
$lang->repo->encryptList['base64'] = 'BASE64';

$lang->repo->logStyles['A'] = 'Ajout';
$lang->repo->logStyles['M'] = 'Modification';
$lang->repo->logStyles['D'] = 'Suppression';

$lang->repo->encodingList['utf_8'] = 'UTF-8';
$lang->repo->encodingList['gbk']   = 'GBK';

$lang->repo->scmList['Git']        = 'Git';
$lang->repo->scmList['Subversion'] = 'Subversion';

$lang->repo->notice                 = new stdclass();
$lang->repo->notice->syncing        = 'Synchronisation en cours. Veuillez patienter ...';
$lang->repo->notice->syncComplete   = 'Synchronisé. Vous allez être redirigé ...';
$lang->repo->notice->syncedCount    = "Le nombre d'enregistrements synchronisés est ";
$lang->repo->notice->delete         = 'Etes vous certain de vouloir supprimer ce référentiel ?';
$lang->repo->notice->successDelete  = 'Le référentiel est supprimé.';
$lang->repo->notice->commentContent = 'Commentaire';
$lang->repo->notice->deleteBug      = 'Êtes-vous sûr de vouloir supprimer ce bug ?';
$lang->repo->notice->deleteComment  = 'Êtes-vous certain de vouloir supprimer ce commentaire ?';
$lang->repo->notice->lastSyncTime   = 'Dern Sync:';

$lang->repo->rules = new stdclass();
$lang->repo->rules->exampleLabel = "Comment Exemple";
$lang->repo->rules->example['task']['start']  = "%start% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['task']['finish'] = "%finish% %task% %id%1%split%2 %cost%%consumedmark%10%cunit%";
$lang->repo->rules->example['task']['effort'] = "%effort% %task% %id%1%split%2 %cost%%consumedmark%1%cunit% %left%%leftmark%3%lunit%";
$lang->repo->rules->example['bug']['resolve'] = "%resolve% %bug% %id%1%split%2";

$lang->repo->error                = new stdclass();
$lang->repo->error->useless       = 'Votre serveur a désactivé exec et shell_exec, il ne peut donc pas être appliqué.';
$lang->repo->error->connect       = "La connexion au référentiel a échoué. Veuillez saisir correctement le nom d'utilisateur, le mot de passe et l'adresse du référentiel !";
$lang->repo->error->version       = 'Version 1.8+ de https et du protocole svn est requis. Veuillez mettre à jour vers la dernière version ! Allez à http://subversion.apache.org/';
$lang->repo->error->path          = "L'adresse du référentiel est le chemin du fichier, ex: /home/test";
$lang->repo->error->cmd           = 'Erreur du Client !';
$lang->repo->error->diff          = 'Deux version doivent être sélectionnées.';
$lang->repo->error->safe          = 'For security reasons, the client version needs to be detected. Please write the version to the file %s. <br /> Execute command: %s';
$lang->repo->error->product       = "Veuillez sélectionner un {$lang->productCommon}!";
$lang->repo->error->commentText   = 'Veuillez entrer du contenu pour une révision !';
$lang->repo->error->comment       = 'Veuillez entrer le contenu du commentaire !';
$lang->repo->error->title         = 'Veuillez saisir un titre !';
$lang->repo->error->accessDenied  = "Vous n'avez pas les privilèges d'accéder au référentiel.";
$lang->repo->error->noFound       = 'Le référentiel est non trouvé.';
$lang->repo->error->noFile        = "%s n'existe pas.";
$lang->repo->error->noPriv        = "Le programme n'a pas les privilèges pour basculer vers %s";
$lang->repo->error->output        = "La commande est: %s\nL'erreur est (%s): %s\n";
$lang->repo->error->clientVersion = "La version du client est trop ancienne, veuillez mettre à niveau ou changer le client SVN";
$lang->repo->error->encoding      = "L'encodage est peut-être erroné. Veuillez modifier l'encodage et réessayer.";

$lang->repo->syncTips      = '<strong>Vous pouvez trouver la référence sur la façon de définir la synchronisation Git à partir de la page se trouvant <a target="_blank" href="https://www.zentao.pm/book/zentaomanual/free-open-source-project-management-software-git-105.html">ici</a>.</strong>';
$lang->repo->encodingsTips = "Les encodages des commentaires de validation peuvent être des valeurs séparées par des virgules，ex: utf-8";

$lang->repo->example              = new stdclass();
$lang->repo->example->client      = new stdclass();
$lang->repo->example->path        = new stdclass();
$lang->repo->example->client->git = "ex: /usr/bin/git";
$lang->repo->example->client->svn = "ex: /usr/bin/svn";
$lang->repo->example->path->git   = "ex: /home/user/myproject";
$lang->repo->example->path->svn   = "ex: http://example.googlecode.com/svn/trunk/myproject";
$lang->repo->example->config      = "Le répertoire de configuration est requis en https. Utilisez '--config-dir' pour générer le répertoire de configuration.";
$lang->repo->example->encoding    = "encodage d'entrée des fichiers";

$lang->repo->typeList['standard']    = 'Standard';
$lang->repo->typeList['performance'] = 'Performance';
$lang->repo->typeList['security']    = 'Securité';
$lang->repo->typeList['redundancy']  = 'Redondance';
$lang->repo->typeList['logicError']  = 'Erreur Logique';
